@@ -27,11 +27,7 @@ describe 'murano::client' do
       let :platform_params do
         case facts[:osfamily]
         when 'Debian'
-          if facts[:os_package_type] == 'debian'
-            { :pythonclient_package_name => 'python3-muranoclient' }
-          else
-            { :pythonclient_package_name => 'python-muranoclient' }
-          end
+          { :pythonclient_package_name => 'python3-muranoclient' }
         when 'RedHat'
           { :pythonclient_package_name => 'python-muranoclient' }
         end
